@@ -1,23 +1,17 @@
+import json
+import os
+import sys
+
 from subprocess import Popen
-from xml.dom import minidom
-import os, sys
-from xml.parsers.expat import ExpatError
 from tempfile import mkstemp
 
+from bs4 import BeautifulSoup, NavigableString
+
 _py3 = sys.version_info >= (3,)
 
-# check if system has simplejson installed, otherwise
-# fall back to json (included in stdlib in 2.6+)
-try:
-    import simplejson as json
-except ImportError:
-    import json
+__version__ = '1.4.0'
 
-__version__ = '1.3.2'
-
-ENV_DICT = {
-    "PATH": "/usr/local/bin/:/usr/bin/",
-    "LD_LIBRARY_PATH": "/usr/local/lib/:/usr/lib/"}
+ENV_DICT = os.environ
 
 
 class Track(object):
@@ -31,13 +25,13 @@ class Track(object):
 
     def __init__(self, xml_dom_fragment):
         self.xml_dom_fragment = xml_dom_fragment
-        self.track_type = self.xml_dom_fragment.attributes['type'].value
-        for el in self.xml_dom_fragment.childNodes:
-            if el.nodeType == 1:
-                node_name = el.nodeName.lower().strip().strip('_')
+        self.track_type = xml_dom_fragment.attrs['type']
+        for el in self.xml_dom_fragment.children:
+            if not isinstance(el, NavigableString):
+                node_name = el.name.lower().strip().strip('_')
                 if node_name == 'id':
                     node_name = 'track_id'
-                node_value = el.firstChild.nodeValue
+                node_value = el.string
                 other_node_name = "other_%s" % node_name
                 if getattr(self, node_name) is None:
                     setattr(self, node_name, node_value)
@@ -84,17 +78,7 @@ class MediaInfo(object):
 
     @staticmethod
     def parse_xml_data_into_dom(xml_data):
-        dom = None
-        try:
-            dom = minidom.parseString(xml_data)
-        except ExpatError:
-            try:
-                dom = minidom.parseString(xml_data.replace("<>00:00:00:00</>", ""))
-            except:
-                pass
-        except:
-            pass
-        return dom
+        return BeautifulSoup(xml_data, "xml")
 
     @staticmethod
     def parse(filename, environment=ENV_DICT):
@@ -110,12 +94,14 @@ class MediaInfo(object):
         xml_dom = MediaInfo.parse_xml_data_into_dom(fp_out.read())
         fp_out.close()
         fp_err.close()
+        os.unlink(fname_out)
+        os.unlink(fname_err)
         return MediaInfo(xml_dom)
 
     def _populate_tracks(self):
         if self.xml_dom is None:
             return
-        for xml_track in self.xml_dom.getElementsByTagName("track"):
+        for xml_track in self.xml_dom.Mediainfo.File.find_all("track"):
             self._tracks.append(Track(xml_track))
 
     @property
